@@ -4,8 +4,7 @@ use crate::{
     utils::SWAY_GIT_TAG,
 };
 use anyhow::{bail, Result};
-use forc_pkg::{check_program_type, manifest_file_missing, Manifest};
-use forc_util::find_manifest_dir;
+use forc_pkg::ManifestFile;
 use fuel_gql_client::client::FuelClient;
 use fuel_tx::{Output, Salt, Transaction};
 use fuel_vm::prelude::*;
@@ -19,10 +18,8 @@ pub async fn deploy(command: DeployCommand) -> Result<fuel_tx::ContractId> {
     } else {
         std::env::current_dir()?
     };
-    let manifest_dir =
-        find_manifest_dir(&curr_dir).ok_or_else(|| manifest_file_missing(curr_dir))?;
-    let manifest = Manifest::from_dir(&manifest_dir, SWAY_GIT_TAG)?;
-    check_program_type(&manifest, manifest_dir, TreeType::Contract)?;
+    let manifest = ManifestFile::from_dir(&curr_dir, SWAY_GIT_TAG)?;
+    manifest.check_program_type(TreeType::Contract)?;
 
     let DeployCommand {
         path,
