@@ -1,7 +1,7 @@
 use crate::cli::InitCommand;
 use crate::utils::defaults;
 use anyhow::{anyhow, Context, Result};
-use forc_util::validate_name;
+use forc_util::{println_green, validate_name};
 use serde::Deserialize;
 use std::fs;
 use std::fs::File;
@@ -52,6 +52,33 @@ struct ContentResponse {
     url: String,
 }
 
+fn print_welcome_message() {
+    let read_the_docs = format!(
+        "Read the Docs:\n- {}\n- {}\n- {}",
+        "Sway Book: https://fuellabs.github.io/sway/latest",
+        "Rust SDK Book: https://fuellabs.github.io/fuels-rs/latest",
+        "TypeScript SDK: https://github.com/FuelLabs/fuels-ts"
+    );
+
+    let join_the_community = format!(
+        "Join the Community:\n- Follow us {}
+- Ask questions in dev-chat on {}",
+        "@SwayLang: https://twitter.com/SwayLang", "Discord: https://discord.com/invite/xfpK4Pe"
+    );
+
+    let report_bugs = format!(
+        "Report Bugs:\n- {}",
+        "Sway Issues: https://github.com/FuelLabs/sway/issues/new"
+    );
+
+    let try_forc = "To compile, use `forc build`, and to run tests use `forc test`";
+
+    println!(
+        "\n{}\n\n----\n\n{}\n\n{}\n\n{}\n\n",
+        try_forc, read_the_docs, join_the_community, report_bugs
+    );
+}
+
 pub fn init(command: InitCommand) -> Result<()> {
     let project_name = command.project_name;
     validate_name(&project_name, "project name")?;
@@ -113,6 +140,10 @@ pub(crate) fn init_new_project(project_name: String) -> Result<()> {
         defaults::default_gitignore(),
     )?;
 
+    println_green(&format!("Successfully created: {}", project_name));
+
+    print_welcome_message();
+
     Ok(())
 }
 
@@ -149,8 +180,30 @@ pub(crate) fn init_from_git_template(project_name: String, example_url: &Url) ->
 
     // Change the project name and authors of the Forc.toml file
     edit_forc_toml(&out_dir, &project_name, &real_name)?;
-    // Change the project name and authors of the Cargo.toml file
-    edit_cargo_toml(&out_dir, &project_name, &real_name)?;
+
+    // If the example has a tests folder, edit the Cargo.toml
+    // Otherwise, create a basic tests template for the project
+    if out_dir.join("tests").exists() {
+        // Change the project name and authors of the Cargo.toml file
+        edit_cargo_toml(&out_dir, &project_name, &real_name)?;
+    } else {
+        // Create the tests directory, harness.rs and Cargo.toml file
+        fs::create_dir_all(out_dir.join("tests"))?;
+
+        fs::write(
+            out_dir.join("tests").join("harness.rs"),
+            defaults::default_test_program(&project_name),
+        )?;
+
+        fs::write(
+            out_dir.join("Cargo.toml"),
+            defaults::default_tests_manifest(&project_name),
+        )?;
+    }
+
+    println_green(&format!("Successfully created: {}", project_name));
+
+    print_welcome_message();
 
     Ok(())
 }
@@ -211,6 +264,14 @@ fn edit_forc_toml(out_dir: &Path, project_name: &str, real_name: &str) -> Result
     manifest_toml["project"]["authors"] = toml_edit::value(authors);
     manifest_toml["project"]["name"] = toml_edit::value(project_name);
 
+    // Remove explicit std entry from copied template
+    if let Some(project) = manifest_toml.get_mut("dependencies") {
+        let _ = project
+            .as_table_mut()
+            .context("Unable to get forc manifest as table")?
+            .remove("std");
+    }
+
     let mut file = File::create(out_dir.join(constants::MANIFEST_FILE_NAME))?;
     file.write_all(manifest_toml.to_string().as_bytes())?;
     Ok(())
@@ -272,6 +333,7 @@ fn download_contents(url: &str, out_dir: &Path, responses: &[ContentResponse]) -
             }
             FileType::Dir => {
                 match &response.name.as_str() {
+                    // Test directory no longer exists, make sure to create this from scratch!!
                     // Only download the directory and its contents if it matches src or tests
                     &constants::SRC_DIR | &constants::TEST_DIRECTORY => {
                         let dir = out_dir.join(&response.name);
